@@ -14,18 +14,21 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from typing import Dict
+from typing import Any, Dict
 from peekingduck.pipeline.nodes.node import AbstractNode
-from .utils.drawfunctions import draw_human_bboxes
+from peekingduck.pipeline.nodes.draw.utils.drawfunctions import draw_bboxes
 
 
 class Node(AbstractNode):
     """Draw node for drawing bboxes onto image"""
-    def __init__(self, config):
+
+    def __init__(self, config: Dict[str, Any]) -> None:
         super().__init__(config, node_path=__name__)
+        self.bbox_thickness = config["bbox_thickness"]
+        self.bbox_color = tuple(config["bbox_color"])
 
-    def run(self, inputs: Dict):
+    def run(self, inputs: Dict[str, Any]) -> Dict[str, Any]:
 
-        draw_human_bboxes(inputs[self.inputs[1]],
-                          inputs[self.inputs[0]])
+        draw_bboxes(inputs["img"], inputs["bboxes"],
+                    self.bbox_color, self.bbox_thickness)  # type: ignore
         return {}
