@@ -26,15 +26,23 @@ from peekingduck.pipeline.nodes.node import AbstractNode
 
 class Node(AbstractNode):
     """Node that processes videos and images as primary source input"""
-    def __init__(self, config):
+
+    def __init__(self, config: Dict[str, Any]) -> None:
         super().__init__(config, node_path=__name__)
 
         self._file_name = None
-        self._output_dir = config["outputdir"]
-        self._prepare_directory(config["outputdir"])
+        self._output_dir = config["output_dir"]
+        self._prepare_directory(config["output_dir"])
         self._fourcc = cv2.VideoWriter_fourcc(*'mp4v')
+        self._image_type = None
+        self._file_path = None
+        self.writer = None
 
-        #initialize for use in run
+    def __del__(self) -> None:
+        if self.writer:
+            self.writer.release()
+
+        # initialize for use in run
         self._file_name = None
         self._file_path = None
         self._image_type = None
@@ -59,28 +67,31 @@ class Node(AbstractNode):
             self._prepare_writer(inputs["filename"],
                                  inputs["img"],
                                  inputs["fps"])
-        else:
-            self._write(inputs["img"])
+
+        self._write(inputs["img"])
 
         return {}
 
-    def _write(self, img: np.array):
+    def _write(self, img: np.array) -> None:
         if self._image_type == "image":
             cv2.imwrite(self._file_path, img)
         else:
-            self.writer.write(img)
+            self.writer.write(img)  # type: ignore
 
-    def _prepare_writer(self, filename: str, img: np.array, fps: int):
+    def _prepare_writer(self, filename: str, img: np.array, fps: int) -> None:
 
-        self._file_name = filename
-        self._image_type = "video"
+        self._file_name = filename  # type: ignore
+        self._file_path = os.path.join(  # type: ignore
+            self._output_dir, filename)  # type: ignore
+
+        self._image_type = "video"  # type: ignore
         if filename.split(".")[-1] in ["jpg", "jpeg", "png"]:
-            self._image_type = "image"
-
-        resolution = img.shape[1], img.shape[0]
-        self._file_path = os.path.join(self._output_dir, filename)
-        self.writer = cv2.VideoWriter(self._file_path, self._fourcc, fps, resolution)
+            self._image_type = "image"  # type: ignore
+        else:
+            resolution = img.shape[1], img.shape[0]
+            self.writer = cv2.VideoWriter(
+                self._file_path, self._fourcc, fps, resolution)
 
     @staticmethod
-    def _prepare_directory(outputdir):
-        os.makedirs(outputdir, exist_ok=True)
+    def _prepare_directory(output_dir) -> None:  # type: ignore
+        os.makedirs(output_dir, exist_ok=True)
