@@ -14,9 +14,10 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 import os
+from typing import List
 
 
-def has_weights(root, path_to_check):
+def has_weights(root: str, path_to_check: List[str]) -> bool:
     """Checks for model weight paths from weights folder
 
     Args:
